@@ -9,7 +9,7 @@ class DjangoStatsdMiddleware(object):
         
         start = time()
         
-        if (settings.STATSD_SERVER && settings.STATSD_PORT):
+        if (hasattr(settings,'STATSD_SERVER') and hasattr(settings,'STATSD_PORT')):
             client = Client(settings.STATSD_SERVER, settings.STATSD_PORT)
         
         return None
\ No newline at end of file
